#! /usr/bin/env python
#
#mpstreamingpeakstest.py
#
#Copyright (c) 2014 by Micron Optics, Inc.  All Rights Reserved
#
"""This file illustrates how to stream peak data from the hyperion using
the multiprocessing enabled HACQStreamer object.

This example will let the hyperion stream data for an alotted time using a 
background process.  All the data is then pulled from a buffer at the end
of this time.  

This also implements two different ways to get the data, and compares the 
time required.  The first approach uses the get_data() method, and the 
second uses get_all_data().  By changing the waitTime, it can be clearly seen 
that get_all_data() is superior for a large buffer.

"""
import sys
import hyperion
import time


if __name__ == '__main__':
    peaksBufferLength = 1000
    waitTime = 0.5 #seconds
    #Note that if the buffer gets full during the wait time, samples will
    #be dropped.
    
    h1 = hyperion.Hyperion('10.0.41.100')


    h1.enable_peak_streaming(streamingDivider = 1)

    hStream = hyperion.HACQStreamer(comm = h1.peakStreamComm, channelList = [1,], 
                                    bufferLength = peaksBufferLength)
    time.sleep(waitTime) 
    t1 = time.clock()
    data = hStream.get_data()
    
    while data != None:
        print data['timeStamp'], data['serialNumber'], len(data[1])
        data = hStream.get_data()
    
    print "Time required with get_data():", time.clock() - t1
    time.sleep(waitTime) 
    t1 = time.clock()
    data = hStream.get_all_data()
    print "Time required with get_all_data():",  time.clock() - t1
    print "Number of samples returned with get_all_data():", len(data)
    hStream.stop_streaming()

    time.sleep(0.1)

    if hStream.is_alive():
        print "Terminating streaming process"
        hStream.terminate()
    else:
        hStream.join()
            

    h1.disable_peak_streaming()
    h1.comm.close()
    
