#! /usr/bin/env python
#
#spectrumplotrttest.py
#
#Copyright (c) 2014 by Micron Optics, Inc.  All Rights Reserved
#
"""This demonstrates a way to do continuous updating of a plot showing
spectrum and corresponding peaks.
"""

import matplotlib
import numpy as np
import matplotlib.pyplot as plt
from scipy.interpolate import interp1d
import matplotlib.animation as animation

import hyperion


class HyperionSpectrumPlot:
    def __init__(self, ax, hyp, channel):
        self.ax = ax
        self.hyp = hyp
        self.channel = channel
        self.hyp.get_peaks()
        channelCount = self.hyp.get_channel_count()
        self.hyp.set_active_full_spectrum_channel_numbers(range(1, channelCount + 1))
        dbmData = self.hyp.get_spectrum(self.channel)
        
        ch1Peaks = self.hyp.peaks.get_channel(channel)
        interpSpectrum = interp1d(self.hyp.wavelengths, dbmData)
        self.lines = self.ax.plot(self.hyp.wavelengths, dbmData,
                    ch1Peaks, interpSpectrum(ch1Peaks), 'o')
        
    def update(self, dum):
        self.hyp.get_peaks()
        dbmData = self.hyp.get_spectrum(self.channel)
        
        ch1Peaks = self.hyp.peaks.get_channel(self.channel)
        interpSpectrum = interp1d(self.hyp.wavelengths, dbmData)
        self.ax.figure.canvas.draw()
        self.lines[0].set_data(self.hyp.wavelengths, dbmData)
        self.lines[1].set_data(ch1Peaks, interpSpectrum(ch1Peaks))
        return self.lines

        

fig, ax = plt.subplots()

ax.set_xlabel('Wavelength (nm)')



#change this IP address to match the instrument
h1 = hyperion.Hyperion('10.0.41.61')


ax.set_ylabel('Amplitude (dBm)')

#select the channels to plot
channel = 1
hPlot = HyperionSpectrumPlot(ax, h1, channel)

ani = animation.FuncAnimation(fig, hPlot.update, interval=100, 
                              blit = True)
plt.show()


plt.close()
h1.comm.close()
